@@ -10,10 +10,10 @@ This module implements the Connect client methods for Request Flow
 
 from typing import List
 
-from .. import consts
 from connect.client import ClientError, R
 
 from .client_manager import ClientManager
+from .. import consts
 from ..request import Asset
 
 
@@ -99,8 +99,10 @@ class RequestClient(ClientManager):
         """
 
         assets_data = self.client.assets.filter(
-            R().tiers.customer.id.eq(customer_id) & R().product.id.eq(product_id) & R().id.ne(asset_id)
-            & R().status.in_(statuses))
+            R().tiers.customer.id.eq(customer_id) &
+            R().product.id.eq(product_id) &
+            R().id.ne(asset_id) &
+            R().status.in_(statuses))
 
         if assets_data.first() is None:
             return []
@@ -118,3 +120,19 @@ class RequestClient(ClientManager):
 
         conversation = self.client.conversations.filter(instance_id=request_id).first()
         return self.client.conversations[conversation[consts.ID]](consts.MESSAGES).post(payload={consts.TEXT: message})
+
+    def get_reseller_assets(self, reseller_id: str, product_id: str, statuses: list) -> List[Asset]:
+        assets_data = self.client.assets.filter(R().tiers.tier1.id.eq(reseller_id) &
+                                                R().product.id.eq(product_id) &
+                                                R().status.in_(statuses))
+        if assets_data.first() is None:
+            return []
+        return [Asset(**a) for a in assets_data]
+
+    def get_customer_assets(self, customer_id: str, product_id: str, statuses: list) -> List[Asset]:
+        assets_data = self.client.assets.filter(R().tiers.customer.id.eq(customer_id) &
+                                                R().product.id.eq(product_id) &
+                                                R().status.in_(statuses))
+        if assets_data.first() is None:
+            return []
+        return [Asset(**a) for a in assets_data]
