@@ -192,7 +192,13 @@ class ParamsManager:
         if not self.params:
             return ''
         param = self.search_param(param_id)
-        return param.value if param else ''
+        value = ''
+        if param:
+            if hasattr(param, 'value'):
+                value = param.value
+            else:
+                raise ConfigurationError(messages.CONFIGURATION_ERROR_PARAMETER.format(id=param_id))
+        return value
 
 
 class Configuration(ParamsManager):
